import { Http, IEventParam, Metadata } from '@zeedhi/core';
import {
  AlertService, Form, Modal, ModalService,
} from '@zeedhi/common';
import { ZdGrid } from '@zeedhi/vuetify';

export class Cmp99000GeracaoAfPrevisaoController {
  public FiltroModal!: Modal;
  
  public dateValue: string | string[] = '';
  
  public filterValueCDFILIOPELOG: any = null;
  
  public filterForm: any = [];
  
  public cdfilialArray: any = [];
  
  public paraSupri: any = [];
  
  public async createFiltroModal() {
    this.FiltroModal = await ModalService.createFromJson('pages/cmp99000/cmp99000_filtro', true);

    this.FiltroModal.show();
  }
  
  public onFilterOpen() {
    this.filterForm = [];
    
    this.getParaSupri();
  }
  
  public selectFiliais({ component }: IEventParam<any>) {
    const nrapurprec = Metadata.getInstance<any>('NRAPURPREC');

    this.cdfilialArray = this.mountArrayFilter(component.selectValue, 'CDFILIAL');
    nrapurprec.datasource.filter.CDFILIAL = this.cdfilialArray;
  }
  
  public selectFornecedor({ component }: IEventParam<any>) {
    const fornecedor = Metadata.getInstance<any>('CDFORNECED');
    const nrapurprec = Metadata.getInstance<any>('NRAPURPREC');

    fornecedor.datasource.filter.P_CDFORNERELACAF = component.selectValue.CDFORNECED;
    nrapurprec.datasource.filter.CDFORNECED = component.selectValue.CDFORNECED;
       
    component.datasource.get().then((response: any) => {
      component.updateData(response);
    });
  }
    
  public selectComprador({ component }: IEventParam<any>) {
    const nrapurprec = Metadata.getInstance<any>('NRAPURPREC');
    nrapurprec.datasource.filter.CDOPERADOR = component.selectValue.CDOPERADOR;
    
    component.datasource.get().then((response: any) => {
      component.updateData(response);
    });
  }
  
  public destroyFiltroModal() {
    this.FiltroModal?.destroy();
  }
  
  public fecharFiltroModal() {
    this.FiltroModal.hide();
  }
  
  public async abrirFiltroModal() {
    this.FiltroModal.show();
  }
  
  public async validaFiltro() {
    const form = Metadata.getInstance<Form>('formFiltro');
    const valid = form.validate();

    if (!valid) {
      AlertService.show({
        top: true,
        right: true,
        timeout: 2000,
        name: 'filtroInvalidoAltert',
        text: 'Preencha todos os campos obrigatórios!',
        color: 'error',
      });
      
      return;
    }
    
    form.submit();
    this.filterForm = form;
    this.loadGrid();
  }
  
  public getFilters() {
    const filterForm = this.filterForm.internalValue;

    const params = {
      CDFORNERELACAF: filterForm.CDFORNERELACAF != null ? filterForm.CDFORNERELACAF.CDFORNECED : 'T',
      CDFORNECED: filterForm.CDFORNECED != null ? filterForm.CDFORNECED.CDFORNECED : 'T',
      CDFILIAL: this.mountArrayFilter(filterForm.CDFILIAL, 'CDFILIAL'),
      CDCOMPRADOR: filterForm.CDCOMPRADOR.CDOPERADOR,
      TIPOPREVISAO: filterForm.TIPOPREVISAO.id,
      CDSUBGRUPPROD: filterForm.CDSUBGRUPPROD != null ? this.mountArrayFilter(filterForm.CDSUBGRUPPROD, 'CDSUBGRPROD') : 'T',
      CDPRODINI: filterForm.CDPRODINI.CDPRODUTO,
      CDPRODFIN: filterForm.CDPRODFIN.CDPRODUTO,
      CDMARCA: filterForm.CDMARCA != null ? this.mountArrayFilter(filterForm.CDMARCA, 'CDMARCA') : 'T',
      DTINICIAL: filterForm.PERIODO[0],
      DTFINAL: filterForm.PERIODO[1],
      QTDIAESTOQUE: filterForm.QTDIAESTOQUE != null ? filterForm.QTDIAESTOQUE.ROW_NUM : null,
      DTENTREGA: filterForm.DTENTREGA,
      CDTIPOCUSTO: filterForm.CDTIPOCUSTO != null ? filterForm.CDTIPOCUSTO.CDTIPOCUSTO : '',
      NRAPURPREC: filterForm.NRAPURPREC != null ? filterForm.NRAPURPREC.NRAPURPREC : null,
      CDFILCENTCMP: this.paraSupri != null ? this.paraSupri.CDFILCENTCMP : '',
      NRORG: this.paraSupri != null ? this.paraSupri.NRORG : '',
    };
    
    return params;
  }
  
  public mountArrayFilter(items: any, fieldName: any) {
    const newArray: Array<any> = [];

    if (items) {
      items.forEach((item: any) => {
        newArray.push(item[fieldName]);
      });
    }
    
    if (newArray.toString() !== 'underfined' && newArray.toString() !== null && newArray.toString() !== '') {
      const concactedArray = newArray.toString().replaceAll(',', '_');
      
      return String('_').concat(concactedArray.concat(String('_')));
    }
    
    return null;
  }
  
  public loadGrid() {
    const filters = this.getFilters();
 
    Http.post('/getGeracaoAfPrevisao', filters).then((response) => {
      const grid = Metadata.getInstance<ZdGrid>('cmp99000Grid');
         
      if (response.data.error) {
        AlertService.show({
          top: true,
          right: true,
          timeout: 2000,
          name: 'noData',
          text: response.data.error,
          color: 'error',
        });
      }
        
      grid.datasource.data = response.data.dataset.data;
    });
    
    this.fecharFiltroModal();
  }
  
  public async getParaSupri() {
    const parasupri = Metadata.getInstance<any>('PARASUPRI');
    const paraSupriData = await parasupri.datasource.get();

    this.paraSupri = paraSupriData[0];

    this.useParaSupri();
  }

  public useParaSupri() {
    if (typeof this.paraSupri !== 'undefined' && typeof this.paraSupri !== null) {
      const subgroup = Metadata.getInstance<any>('CDSUBGRUPPROD');
      const nrapurprec = Metadata.getInstance<any>('NRAPURPREC');
        
      subgroup.datasource.filter.P_CDGRUPPROD = this.paraSupri.CDGRUPPROD;
      nrapurprec.datasource.filter.CDFILCENTCMP = this.paraSupri.CDFILCENTCMP;
       
      subgroup.datasource.get().then((response: any) => {
        subgroup.updateData(response);
      });
    }
  }
}
